@@ -11,5 +11,5 @@ class CeleryResultConfig(AppConfig):
     """Default configuration for the django_celery_results app."""
 
     name = 'django_celery_results'
-    label = 'celery_results'
+    label = 'django_celery_results'
     verbose_name = _('Celery Results')
